function make_pr_plot(models) {
  var svg, chart_group, data_extent, canvas, margins, max_draw_space, doc_state
  var plot = "precision_recall"
  var plot_cv = "precision_recall_cross_validation_error"
  // extract current model
  var model = extractModel(models)
  // extract corresponding data
  var data = model[plot]
  var data_cv = model[plot_cv]

  var output_container_id = charts_config.chart_container
  svg = make_chart_svg(plot)
  if (svg.select("g.plot_group").empty()) {
    chart_group = svg.append("g").attr("class", "plot_group")
    charts_config.document_state.current_plot = plot
  } else {
    chart_group = svg.select("g.plot_group")
  }

  var data_extent, data_extent_cv, x_axis_label, y_axis_label, comb_data_ext
  data_extent = {
    "max": {
      "x": d3.max(data, function(d) {return d.x}),
      "y": d3.max(data, function(d) {return d.y})
    },
    "min": {
      "x": d3.min(data, function(d) {return d.x}),
      "y": d3.min(data, function(d) {return d.y})
    }
  }


  data_extent_cv = {
    "max": {
      "x": d3.max(data_cv, function(d) {return d.x}),
      "y": d3.max(data_cv, function(d) {return d.y})
    },
    "min": {
      "x": d3.min(data_cv, function(d) {return d.x}),
      "y": d3.min(data_cv, function(d) {return d.y})
    }
  }

  comb_data_ext = {
    "max": {
      "x": Math.max(data_extent.max.x, data_extent_cv.max.x),
      "y": Math.max(data_extent.max.y, data_extent_cv.max.y)
    },
    "min": {
      "x": Math.min(data_extent.min.x, data_extent_cv.min.x),
      "y": Math.min(data_extent.min.y, data_extent_cv.min.y)
    }
  }


  x_axis_label = "Recall"
  y_axis_label = "Precision"
  canvas = extract_canvas_from_svg(svg)
  margins = make_margins(chart_group, canvas, comb_data_ext, true)
  max_draw_space = calculate_maximum_drawing_space(canvas, margins)
  make_title(chart_group, ["Precision Recall Plot"], margins, canvas, max_draw_space)
  var x_scale = d3.scaleLinear().domain([comb_data_ext.min.x, comb_data_ext.max.x]).range([0, max_draw_space.x])
  var y_scale = d3.scaleLinear().domain([comb_data_ext.max.y, comb_data_ext.min.y]).range([0, max_draw_space.y])
  make_axes(chart_group, x_scale, y_scale, canvas, margins, max_draw_space, x_axis_label, y_axis_label)

  var line = d3.line().x(function (d) {return x_scale(d.x) + margins.x.left + margins.axes.y}).y(function (d) {return y_scale(d.y)+ margins.y.top + margins.title + margins.buttons})
  var line_cv = d3.line().x(function (d) {return x_scale(d.x) + margins.x.left + margins.axes.y}).y(function (d) {return y_scale(d.y)+ margins.y.top + margins.title + margins.buttons})
  if (chart_group.selectAll("g." + plot + "_line_group").empty()) {
    // Add the group for the line
    chart_group.append("g").attr("class", plot + "_line_group").append("path")

    chart_group.selectAll("g." + plot + "_point_group")
              .data(data)
              .enter()
              .append("g")
              .attr("class", plot + "_point_group")
              .append("circle")
              .attr("r", charts_config.plots.line.hidden_radius)
              .style("opacity", 0)


    // Add the group for the line_cv
    chart_group.append("g").attr("class", plot_cv + "_line_group").append("path")

    chart_group.selectAll("g." + plot_cv + "_point_group")
              .data(data_cv)
              .enter()
              .append("g")
              .attr("class", plot_cv + "_point_group")
              .append("circle")
              .attr("r", charts_config.plots.line.hidden_radius)
              .style("opacity", 0)

  }

  var line_group = d3.selectAll("g." + plot + "_line_group").data(data)
  var line_cv_group = d3.selectAll("g." + plot_cv + "_line_group").data(data_cv)
  line_group.select("path")
            .data([data])
            .attr("class", "line")
            .attr("d", line)
            .attr("fill", charts_config.plots.line.fill)
            .attr("stroke", charts_config.plots.line.stroke)
            .attr("stroke-width", charts_config.plots.line.width)

  line_cv_group.select("path")
            .data([data_cv])
            .attr("class", "line")
            .attr("d", line_cv)
            .attr("fill", charts_config.plots.line.fill)
            .attr("stroke", charts_config.colors.palette[0])
            .attr("stroke-width", charts_config.plots.line.width)

  var point_group = d3.selectAll("g." + plot + "_point_group").data(data)
  var point_cv_group = d3.selectAll("g." + plot_cv + "_point_group").data(data_cv)

  point_group.attr("transform", function(d, i) {return "translate(" + (x_scale(d.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.y)+ margins.y.top + margins.title + margins.buttons) + ")"})
  point_cv_group.attr("transform", function(d, i) {return "translate(" + (x_scale(d.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.y)+ margins.y.top + margins.title + margins.buttons) + ")"})

  point_group.on("mouseover", mouseoverFunction)
  point_group.on("mouseout", mouseoutFunction)
  point_cv_group.on("mouseover", mouseoverFunction)
  point_cv_group.on("mouseout", mouseoutFunction)

 function mouseoverFunction(d, i) {
   var class_name = d3.select(this).node().className.baseVal
   var this_circle = d3.select(this).select("circle")
   this_circle.style("opacity", charts_config.plots.line.opacity.hover).style("fill", charts_config.plots.line.stroke)
   var tooltip_text = "PR"
   if (class_name.includes("cross")) {
     this_circle.style("fill", charts_config.colors.palette[0])
     tooltip_text = "PR_CV"
   }
   x = x_scale(d.x) + margins.x.left + margins.axes.y
   y = y_scale(d.y) + margins.y.top + margins.title + margins.buttons
   make_tooltip(d3.select(this), [tooltip_text, "Recall: " + d.x, "Precision: " + d.y], chart_group, canvas, margins)
 }

 function mouseoutFunction(d, i) {
  chart_group.select("g.tooltip_group").remove()
  d3.select(this).select("circle").style("opacity", 0)
 }

}






// 
//
// function make_pr_plot(models) {
//   var svg, chart_group, data_extent, canvas, margins, max_draw_space, doc_state
//   var plot = "precision_recall"
//   var plot_cv = "precision_recall_cross_validation_error"
//   // extract current model
//   var model = extractModel(models)
//   // extract corresponding data
//   var data = {"pr": model[plot], "pr_cv": model[plot_cv]}
//
//   svg = make_chart_svg(plot)
//   if (svg.select("g.plot_group").empty()) {
//     chart_group = svg.append("g").attr("class", "plot_group")
//   } else {
//     chart_group = svg.select("g.plot_group")
//   }
//
//   var data_extent, data_extent_cv, x_axis_label, y_axis_label, comb_data_ext
//   data_extent = {
//     "max": {
//       "x": d3.max(data, function(d) {return Math.max(d.pr.x, d.pr_cv.x)}),
//       "y": d3.max(data, function(d) {return Math.max(d.pr.y, d.pr_cv.y)})
//     },
//     "min": {
//       "x": d3.min(data, function(d) {return Math.min(d.pr.x, d.pr_cv.x)}),
//       "y": d3.min(data, function(d) {return Math.min(d.pr.y, d.pr_cv.y)})
//     }
//   }
//
//   x_axis_label = "Recall"
//   y_axis_label = "Precision"
//   canvas = extract_canvas_from_svg(svg)
//   margins = make_margins(chart_group, canvas, data_extent, true)
//   max_draw_space = calculate_maximum_drawing_space(canvas, margins)
//   make_title(chart_group, ["Precision Recall Plot"], margins, canvas, max_draw_space)
//   var x_scale = d3.scaleLinear().domain([comb_data_ext.min.x, comb_data_ext.max.x]).range([0, max_draw_space.x])
//   var y_scale = d3.scaleLinear().domain([comb_data_ext.max.y, comb_data_ext.min.y]).range([0, max_draw_space.y])
//   make_axes(chart_group, x_scale, y_scale, canvas, margins, max_draw_space, x_axis_label, y_axis_label)
//
//   var line = d3.line().x(function (d) {return x_scale(d.x) + margins.x.left + margins.axes.y}).y(function (d) {return y_scale(d.y)+ margins.y.top + margins.title + margins.buttons})
//   var line_cv = d3.line().x(function (d) {return x_scale(d.x) + margins.x.left + margins.axes.y}).y(function (d) {return y_scale(d.y)+ margins.y.top + margins.title + margins.buttons})
//   if (chart_group.selectAll("g." + plot + "_line_group").empty()) {
//     // Add the group for the line
//     chart_group.append("g").attr("class", plot + "_line_group").append("path")
//
//     chart_group.selectAll("g." + plot + "_point_group")
//               .data(data)
//               .enter()
//               .append("g")
//               .attr("class", plot + "_point_group")
//               .append("circle")
//               .attr("r", charts_config.plots.line.hidden_radius)
//               .style("opacity", 0)
//
//
//     // Add the group for the line_cv
//     chart_group.append("g").attr("class", plot_cv + "_line_group").append("path")
//
//     chart_group.selectAll("g." + plot_cv + "_point_group")
//               .data(data_cv)
//               .enter()
//               .append("g")
//               .attr("class", plot_cv + "_point_group")
//               .append("circle")
//               .attr("r", charts_config.plots.line.hidden_radius)
//               .style("opacity", 0)
//
//   }
//
//   var line_group = d3.selectAll("g." + plot + "_line_group").data(data)
//   var line_cv_group = d3.selectAll("g." + plot_cv + "_line_group").data(data_cv)
//   line_group.select("path")
//             .data([data])
//             .attr("class", "line")
//             .attr("d", line)
//             .attr("fill", charts_config.plots.line.fill)
//             .attr("stroke", charts_config.plots.line.stroke)
//             .attr("stroke-width", charts_config.plots.line.width)
//
//   line_cv_group.select("path")
//             .data([data_cv])
//             .attr("class", "line")
//             .attr("d", line_cv)
//             .attr("fill", charts_config.plots.line.fill)
//             .attr("stroke", charts_config.colors.palette[0])
//             .attr("stroke-width", charts_config.plots.line.width)
//
//   var point_group = d3.selectAll("g." + plot + "_point_group").data(data)
//   var point_cv_group = d3.selectAll("g." + plot_cv + "_point_group").data(data_cv)
//
//   point_group.attr("transform", function(d, i) {return "translate(" + (x_scale(d.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.y)+ margins.y.top + margins.title + margins.buttons) + ")"})
//   point_cv_group.attr("transform", function(d, i) {return "translate(" + (x_scale(d.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.y)+ margins.y.top + margins.title + margins.buttons) + ")"})
//
//   point_group.on("mouseover", mouseoverFunction)
//   point_group.on("mouseout", mouseoutFunction)
//   point_cv_group.on("mouseover", mouseoverFunction)
//   point_cv_group.on("mouseout", mouseoutFunction)
//
//  function mouseoverFunction(d, i) {
//    var class_name = d3.select(this).node().className.baseVal
//    var this_circle = d3.select(this).select("circle")
//    this_circle.style("opacity", charts_config.plots.line.opacity.hover).style("fill", charts_config.plots.line.stroke)
//    var tooltip_text = "PR"
//    if (class_name.includes("cross")) {
//      this_circle.style("fill", charts_config.colors.palette[0])
//      tooltip_text = "PR_CV"
//    }
//    x = x_scale(d.x) + margins.x.left + margins.axes.y
//    y = y_scale(d.y) + margins.y.top + margins.title + margins.buttons
//    make_tooltip(d3.select(this), [tooltip_text, "Recall: " + d.x, "Precision: " + d.y], chart_group, canvas, margins)
//  }
//
//  function mouseoutFunction(d, i) {
//   chart_group.select("g.tooltip_group").remove()
//   d3.select(this).select("circle").style("opacity", 0)
//  }
//
// }
