function ajaxOldJSON(file) {
  var data = $.ajax({
    url: file,
    async: false,
    dataType: 'json',
    success: function (data) {
      return data
    }
  });
  return transformOldJSON(data.responseJSON)
}

//-------------------------------------------------------------------//
//                                                                   //
//                       TRANSFORM OLD JSON                          //
//                                                                   //
//-------------------------------------------------------------------//
function transformOldJSON(json) {
  var pca_total, pca_variance, outliers, error_cv, error, variables, roc, pr, prcv, features, features_new
  pca_total = json.pca_total
  pca_variance = json.pca_variance
  outliers = json.outliers
  error_cv = json.error_cv_samples
  error = json.error
  variables = json.variables
  roc = json.roc
  pr = json.pr
  prcv = json.pr_cv
  features = json.features
  features_new = json.features_new

  var data = {
    "statistics": {},
    "principal_component_analysis": {"samples": [], "component_variance": {}},
    "outliers": [],
    "receiver_operating_characteristic": {"true_positive_rate": []},
    "precision_recall": [],
    "precision_recall_cross_validation_error": [],
    "variable_importance": [],
    "feature_selection": [],
    "feature_selection_new": [],
    "out_of_bag_error": []
  }

  // Add statistics
  data.statistics = json.statistics

  // Add component values to PCA object
  data.principal_component_analysis.component_variance.prinicpal_component_1 = pca_variance[0].variance
  data.principal_component_analysis.component_variance.prinicpal_component_2 = pca_variance[1].variance

  // Add distance sample values to PCA object
  for (var i = 0; i < pca_total.length; i++) {
    var obj = pca_total[i]
    var sample = {}
    sample.sample = obj.key
    sample.group = obj.values.group
    sample.distance = {}
    sample.distance.x = obj.values.x
    sample.distance.y = obj.values.y
    data.principal_component_analysis.samples.push(sample)
  }

  // Add outlier values to PCA object

  // Sort outlier and cross-val. error by sample so they are in same order
  error_cv.sort(function(a, b) {return a.label - b.label})
  outliers.sort(function(a, b) {return a.key - b.key})

  for (var i = 0; i < outliers.length; i++) {
    var obj = outliers[i]
    var sample = {}
    sample.outlier = obj.values.y
    sample.sample = obj.key
    sample.group = obj.values.group
    var obj = error_cv[i]
    sample.cross_validation_error = obj.value
    data.outliers.push(sample)
  }

  // Add OOB values
  var t = error[0].values
  var c =error[1].values
  var b =error[2].values
  for (var i = 0; i < t.length; i++) {
    var tree = {}

    tree.trees = t[i].x
    tree.conditions = {
      "treatment": t[i].y,
      "control": c[i].y,
      "both": b[i].y
    }

    data.out_of_bag_error.push(tree)
  }

  // Add variables values
  for (var i = 0; i < variables.length; i++) {
    var obj = variables[i]
    var importance = {}
    importance.variable = obj.key
    importance.gini_score = obj.values.x
    if (importance.gini_score !="NA") {
      data.variable_importance.push(importance)
    }
  }

  // Add roc values
  for (var i = 0; i < roc.length; i++) {
    var obj = roc[i]
    var point = {}
    point.x = obj.values.x
    point.y = obj.values.y
    data.receiver_operating_characteristic.true_positive_rate.push(point)
  }

  // Add PR values
  for (var i = 0; i < pr.length; i++) {
    var obj = pr[i]
    var point = {}

    point.x = obj.values.x
    point.y = obj.values.y

    data.precision_recall.push(point)
  }


  // Add PR_CV values
  for (var i = 0; i < prcv.length; i++) {
    var obj = prcv[i]
    var point = {}

    point.x = obj.values.x
    point.y = obj.values.y

    data.precision_recall_cross_validation_error.push(point)
  }

  // Add feature values
  for (var i = 0; i < features.length; i++) {
    var obj = features[i]
    var feature = {}
    feature.quantiles = {}

    feature.number_of_features = obj.label

    feature.quantiles["0.25"] = obj.values["Q1"]
    feature.quantiles["0.50"] = obj.values["Q2"]
    feature.quantiles["0.75"] = obj.values["Q3"]
    feature.min = obj.whisker_low
    feature.max = obj.whisker_high

    data.feature_selection.push(feature)
  }

  // Add new feature values
  for (var i = 0; i < features_new.length; i++) {
    var obj = features_new[i]
    var feature_new = {}
    feature_new.quantiles = {}

    feature.number_of_features = obj.label
    feature.optimal_number_of_features = obj.optimal
    feature.quantiles["0.00"] = obj.values.whisker_low
    feature.quantiles["0.25"] = obj.values["Q1"]
    feature.quantiles["0.50"] = obj.values["Q2"]
    feature.quantiles["0.75"] = obj.values["Q3"]
    feature.quantiles["1.00"] = obj.values.whisker_high

    data.feature_selection_new.push(feature)
  }


  return data
}
