# html_configuration
The file _html_configuration.json_ is initially read by _setup_html.js_.
It contains two main keys:
  - head
  - body

### html_configuration.head
The former contains attributes which are to be injected into the head of the
html document. They are currently stored as plurals of their html tag equivalent
e.g. scripts vs script. The function _populate_head(html_config)_ in
_assets/js/setup_html.js_ will read these plurals and create the corresponding
elements. Each plural (e.g. scripts) is a list of objects where the keys are
attributes of the respective tag (e.g. src of the script tag).  The file
_core_helper_functions.js_ contains the function
_set_attributes(element, data, attributes_to_ignore)_ where data is a object
such that the keys are attributes of the passed element which will be set to the
object's corresponding values e.g.

set_attributes(
  document.createElement("script"),
  {"src": "my_script.js"}
  )

will give the newly created script tag the src property set to "my_script.js"


### html_configuration.body
The body key of the html_configuration object is less structured than that of
html_configuration.head. Currently body has to main subkeys:
  - header
    + id
    + logo
    + navigation
  - output
    + id
    + charts_container_id
    + charts

The file _assets/js/setup_html.js_ will utilize the values stored in
html_configuration.body.header in _populate_navigation(config)_ to generate
the horizontal navigation bar as a child of the element
_html_configuration.body.header.id_ which starts with logo and then those values
which are listed under _html_configuration.body.header.navigation_.

The file _assets/js/setup_charts.js_ will call various chart functions found
under _assets/js/magruder_.  The key-value pair under
_html_configuration.body.output.charts_container_id_ will be used by these
functions to generate sub-sections containing the relevant plots, each with a
title and explanation as seen under _html_configuration.body.output.charts_.


-----

# charts_configuration
This file is more complex than the previous html configuration file. The core
keys are as follows:
  - files
  - document_state
  - chart_container
  - chart_ids
  - table_id
  - svg
  - plot_attributes
  - plots
  - colors

### files
The key _files_ is not generalizable outside the specific use case of Oasis's
classification output. Currently the file _assets/js/setup_charts.js_ has a
function _loadModels()_ which will read from the key files value to generate
as JSON object stored in the global variable _models_, which is used for the
generation of all plots.

### document_state
Since we produce more than one model and since we give the user to choose which
model they would like to visualize at the moment, we require a means for
knowing which model should be displayed. The key _document_state_ provides this
functionality. Although - currently - the drag box has two checkboxes for
switching between which model is displayed, ultimately the _document_state_
solely effects the charts. Hence this key is located here rather than under
the html_configuration object.

Further in _assets/js/setup_charts.js_ the function _extractModel()_ reads this
key-value pair to determine which data should be used in drawing the charts.

### chart_container
This simply stores the related html element id for where the charts should be
injected.

### chart_ids
These values will be given to the injected charts. In addition, the chart
functions will reference these ids to see whether or not the chart exists
already.

### table_id
This simply stores the related html element id for where the statistics overview
table should be placed.

### svg
Currently this stores some objects regarding how large the svg should be.
This can be absolute (e.g. 500px) or in percentage. If a percentage is used
the function _make_svg(plot)_ under _assets/js/magruder/make_svg.js_ will
set the svg to be the corresponding percentage of the _clientWidth_ of the
corresponding chart section. Since the charts are dynamically injected
the _clientHeight_ will almost always be very small. This behavior can be
modified to meet specific output as needed e.g. width / height of body.

### plot_attributes
This key stores general stylistic properties of _all_ charts e.g.
size of chart title, color of tooltip, etc.

### plots
This key stores general properties of specific chart _types_ e.g.
the radius of a point rendered in a scatter plot, the spacing between boxes for
a box and whisker chart, etc.

### colors
This stores the color palette from which colors are chosen.
